# Synchronizing Subscriptions Across Related Fact Sheets (Subscription Inheritance)
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/synchronizing-subscriptions-across-related-fact-sheets-subscription-inheritance#overview)
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/synchronizing-subscriptions-across-related-fact-sheets-subscription-inheritance#prerequisites)
  * [Automation Logic](https://help.sap.com/docs/leanix/ea/synchronizing-subscriptions-across-related-fact-sheets-subscription-inheritance#automation-logic)
  * [How It Works: Example](https://help.sap.com/docs/leanix/ea/synchronizing-subscriptions-across-related-fact-sheets-subscription-inheritance#how-it-works:-example)
  * [Technical Details](https://help.sap.com/docs/leanix/ea/synchronizing-subscriptions-across-related-fact-sheets-subscription-inheritance#technical-details)
  * [Configuration](https://help.sap.com/docs/leanix/ea/synchronizing-subscriptions-across-related-fact-sheets-subscription-inheritance#configuration)
  * [Automation 1: Subscription Is Added](https://help.sap.com/docs/leanix/ea/synchronizing-subscriptions-across-related-fact-sheets-subscription-inheritance#automation-1:-subscription-is-added)
  * [Automation 2: Subscription Is Removed](https://help.sap.com/docs/leanix/ea/synchronizing-subscriptions-across-related-fact-sheets-subscription-inheritance#automation-2:-subscription-is-removed)


View all
Configure automations with scripts to automatically synchronize subscriptions across related fact sheets.
